mizu API documentation
Description: mizu 💧 …

# Package `mizu`

# mizu 💧

Documentation

Mizu written by rust and used pulldown-cmark.

## Installation

    pip install mizu

Or

    pip install "mizu @ git+https://github.com/tuna2134/mizu"

## Performance

These performance test codes are in tests.

`26ms`

## Example

Basic:

    from mizu import parse

    parse("# Hello tuna2134")

Extension:

    from mizu import parse_ext

    parse_ext("""
    - [ ] test
    - [ ] test2
    """)

Expand source code

    """
    .. include:: ../README.md
    """

    from .mizu import parse, parse_ext

    __all__ = ("parse", "parse_ext")

## Sub-modules

`mizu.mizu`

  Mizu's core

## Functions

`def parse(...)`

  This function is parse markdown to html.

  ## Args

  `text` :`str`
    Markdown content.

  ## Returns

  `str`
    Html content.
`def parse_ext(...)`

  This function is parse markdown to html.

  ## Args

  `text` :`str`
    Markdown content.
  `tables` :`Optional[bool]`
    Enable tables.
  `footnotes` :`Optional[bool]`
    Enable footnotes.
  `strikethrough` :`Optional[bool]`
    Enable strikethrough.
  `tasklists` :`Optional[bool]`
    Enable tasklists.
  `smart_punctuation` :`Optional[bool]`
    Enable smart_punctuation.
  `heading_attribute` :`Optional[bool]`
    Enable heading_attribute.

  ## Returns

  `str`
    Html content.